@@ -28,7 +28,6 @@
 #include "dpiManager.h"
 #include "NppDarkMode.h"
 #include <assert.h>
-#include <tchar.h>
 #include <map>
 #include <array>
 #include <shlwapi.h>
@@ -54,7 +53,7 @@
 class NativeLangSpeaker;
 
 const bool POS_VERTICAL = true;
-const bool POS_HORIZOTAL = false;
+const bool POS_HORIZONTAL = false;
 
 const int UDD_SHOW   = 1; // 0000 0001
 const int UDD_DOCKED = 2; // 0000 0010
@@ -89,7 +88,7 @@ enum class EolType: std::uint8_t
 	unix,
 
 	// special values
-	unknown, // can not be the first value for legacy code
+	unknown, // cannot be the first value for legacy code
 	osdefault = windows,
 };
 
@@ -106,12 +105,12 @@ EolType convertIntToFormatType(int value, EolType defvalue = EolType::osdefault)
 enum UniMode {
 	uni8Bit       = 0,  // ANSI
 	uniUTF8       = 1,  // UTF-8 with BOM
-	uni16BE       = 2,  // UTF-16 Big Ending with BOM
-	uni16LE       = 3,  // UTF-16 Little Ending with BOM
+	uni16BE       = 2,  // UTF-16 Big Endian with BOM
+	uni16LE       = 3,  // UTF-16 Little Endian with BOM
 	uniCookie     = 4,  // UTF-8 without BOM
 	uni7Bit       = 5,  // 
-	uni16BE_NoBOM = 6,  // UTF-16 Big Ending without BOM
-	uni16LE_NoBOM = 7,  // UTF-16 Little Ending without BOM
+	uni16BE_NoBOM = 6,  // UTF-16 Big Endian without BOM
+	uni16LE_NoBOM = 7,  // UTF-16 Little Endian without BOM
 	uniEnd};
 
 enum ChangeDetect { cdDisabled = 0x0, cdEnabledOld = 0x01, cdEnabledNew = 0x02, cdAutoUpdate = 0x04, cdGo2end = 0x08 };
@@ -220,8 +219,8 @@ public:
 
 struct sessionFileInfo : public Position
 {
-	sessionFileInfo(const wchar_t* fn, const wchar_t *ln, int encoding, bool userReadOnly,bool isPinned, const Position& pos, const wchar_t *backupFilePath, FILETIME originalFileLastModifTimestamp, const MapPosition & mapPos) :
-		Position(pos), _encoding(encoding), _isUserReadOnly(userReadOnly), _isPinned(isPinned), _originalFileLastModifTimestamp(originalFileLastModifTimestamp), _mapPos(mapPos)
+	sessionFileInfo(const wchar_t* fn, const wchar_t *ln, int encoding, bool userReadOnly,bool isPinned, bool isUntitleTabRenamed, const Position& pos, const wchar_t *backupFilePath, FILETIME originalFileLastModifTimestamp, const MapPosition & mapPos) :
+		Position(pos), _encoding(encoding), _isUserReadOnly(userReadOnly), _isPinned(isPinned), _isUntitledTabRenamed(isUntitleTabRenamed), _originalFileLastModifTimestamp(originalFileLastModifTimestamp), _mapPos(mapPos)
 	{
 		if (fn) _fileName = fn;
 		if (ln)	_langName = ln;
@@ -240,6 +239,7 @@ struct sessionFileInfo : public Position
 	int _individualTabColour = -1;
 	bool _isRTL = false;
 	bool _isPinned = false;
+	bool _isUntitledTabRenamed = false;
 	std::wstring _backupFilePath;
 	FILETIME _originalFileLastModifTimestamp {};
 
@@ -610,6 +610,7 @@ struct NewDocDefaultSettings final
 	LangType _lang = L_TEXT;
 	int _codepage = -1; // -1 when not using
 	bool _addNewDocumentOnStartup = false;
+	bool _useContentAsTabName = false;
 };
 
 
@@ -945,9 +946,10 @@ struct NppGUI final
 	// items with no Notepad++ GUI to set
 	std::wstring _commandLineInterpreter = CMD_INTERPRETER;
 
+	enum AutoUpdateMode { autoupdate_disabled, autoupdate_on_startup, autoupdate_on_exit };
 	struct AutoUpdateOptions
 	{
-		bool _doAutoUpdate = true;
+		AutoUpdateMode _doAutoUpdate = autoupdate_on_startup;
 		int _intervalDays = 15;
 		Date _nextUpdateDate;
 		AutoUpdateOptions(): _nextUpdateDate(Date()) {};
@@ -1052,7 +1054,7 @@ struct ScintillaViewParams
 	unsigned char _paddingLeft = 0;  // 0-9 pixel
 	unsigned char _paddingRight = 0; // 0-9 pixel
 
-	// distractionFreeDivPart is used for divising the fullscreen pixel width.
+	// distractionFreeDivPart is used for dividing the fullscreen pixel width.
 	// the result of division will be the left & right padding in Distraction Free mode
 	unsigned char _distractionFreeDivPart = 4;     // 3-9 parts
 
@@ -1267,7 +1269,7 @@ public:
 struct FindHistory final
 {
 	enum searchMode{normal, extended, regExpr};
-	enum transparencyMode{none, onLossingFocus, persistant};
+	enum transparencyMode{none, onLosingFocus, persistent};
 
 	bool _isSearch2ButtonsMode = false;
 
@@ -1287,14 +1289,14 @@ struct FindHistory final
 	bool _isDirectionDown = true;
 	bool _dotMatchesNewline = false;
 
-	bool _isFifRecuisive = true;
+	bool _isFifRecursive = true;
 	bool _isFifInHiddenFolder = false;
     bool _isFifProjectPanel_1 = false;
     bool _isFifProjectPanel_2 = false;
     bool _isFifProjectPanel_3 = false;
 
 	searchMode _searchMode = normal;
-	transparencyMode _transparencyMode = onLossingFocus;
+	transparencyMode _transparencyMode = onLosingFocus;
 	int _transparency = 150;
 
 	bool _isFilterFollowDoc = false;
@@ -1616,7 +1618,7 @@ public:
 	bool writeColumnEditorSettings() const;
 	bool writeFileBrowserSettings(const std::vector<std::wstring> & rootPath, const std::wstring & latestSelectedItemPath) const;
 
-	TiXmlNode* getChildElementByAttribut(TiXmlNode *pere, const wchar_t *childName, const wchar_t *attributName, const wchar_t *attributVal) const;
+	TiXmlNode* getChildElementByAttribute(TiXmlNode *pere, const wchar_t *childName, const wchar_t *attributeName, const wchar_t *attributeVal) const;
 
 	bool writeScintillaParams();
 	void createXmlTreeFromGUIParams();
@@ -1745,7 +1747,7 @@ public:
 	const wchar_t * getWorkingDir() const {return _currentDirectory.c_str();};
 	const wchar_t * getWorkSpaceFilePath(int i) const {
 		if (i < 0 || i > 2) return nullptr;
-		return _workSpaceFilePathes[i].c_str();
+		return _workSpaceFilePaths[i].c_str();
 	};
 
 	const std::vector<std::wstring> getFileBrowserRoots() const { return _fileBrowserRoot; };
@@ -1785,7 +1787,7 @@ public:
 
 	int langTypeToCommandID(LangType lt) const;
 
-	struct FindDlgTabTitiles final {
+	struct FindDlgTabTitles final {
 		std::wstring _find;
 		std::wstring _replace;
 		std::wstring _findInFiles;
@@ -1793,7 +1795,7 @@ public:
 		std::wstring _mark;
 	};
 
-	FindDlgTabTitiles & getFindDlgTabTitiles() { return _findDlgTabTitiles;};
+	FindDlgTabTitles & getFindDlgTabTitles() { return _findDlgTabTitles;};
 
 	bool asNotepadStyle() const {return _asNotepadStyle;};
 
@@ -1801,8 +1803,8 @@ public:
 		return getPluginCmdsFromXmlTree();
 	}
 
-	bool getContextMenuFromXmlTree(HMENU mainMenuHadle, HMENU pluginsMenu, bool isEditCM = true);
-	bool reloadContextMenuFromXmlTree(HMENU mainMenuHadle, HMENU pluginsMenu);
+	bool getContextMenuFromXmlTree(HMENU mainMenuHandle, HMENU pluginsMenu, bool isEditCM = true);
+	bool reloadContextMenuFromXmlTree(HMENU mainMenuHandle, HMENU pluginsMenu);
 	winVer getWinVersion() const {return _winVersion;};
 	std::wstring getWinVersionStr() const;
 	std::wstring getWinVerBitStr() const;
@@ -1994,7 +1996,7 @@ public:
 
 private:
 	bool _isAnyShortcutModified = false;
-	std::vector<CommandShortcut> _shortcuts;			//main menu shortuts. Static size
+	std::vector<CommandShortcut> _shortcuts;			//main menu shortcuts. Static size
 	std::vector<size_t> _customizedShortcuts;			//altered main menu shortcuts. Indices static. Needed when saving alterations
 	std::vector<MacroShortcut> _macros;				//macro shortcuts, dynamic size, defined on loading macros and adding/deleting them
 	std::vector<UserCommand> _userCommands;			//run shortcuts, dynamic size, defined on loading run commands and adding/deleting them
@@ -2029,7 +2031,7 @@ private:
 	std::wstring _pluginConfDir; // plugins config dir where the plugin list is installed
 	std::wstring _userPluginConfDir; // plugins config dir for per user where the plugin parameters are saved / loaded
 	std::wstring _currentDirectory;
-	std::wstring _workSpaceFilePathes[3];
+	std::wstring _workSpaceFilePaths[3];
 
 	std::vector<std::wstring> _fileBrowserRoot;
 	std::wstring _fileBrowserSelectedItemPath;
@@ -2037,7 +2039,7 @@ private:
 	Accelerator* _pAccelerator = nullptr;
 	ScintillaAccelerator* _pScintAccelerator = nullptr;
 
-	FindDlgTabTitiles _findDlgTabTitiles;
+	FindDlgTabTitles _findDlgTabTitles;
 	bool _asNotepadStyle = false;
 
 	winVer _winVersion = WV_UNKNOWN;
@@ -2150,7 +2152,7 @@ private:
 	void writePrintSetting(TiXmlElement *element);
 	void initMenuKeys();		//initialise menu keys and scintilla keys. Other keys are initialized on their own
 	void initScintillaKeys();	//these functions have to be called first before any modifications are loaded
-	int getCmdIdFromMenuEntryItemName(HMENU mainMenuHadle, const std::wstring& menuEntryName, const std::wstring& menuItemName); // return -1 if not found
+	int getCmdIdFromMenuEntryItemName(HMENU mainMenuHandle, const std::wstring& menuEntryName, const std::wstring& menuItemName); // return -1 if not found
 	int getPluginCmdIdFromMenuEntryItemName(HMENU pluginsMenu, const std::wstring& pluginName, const std::wstring& pluginCmdName); // return -1 if not found
 	winVer getWindowsVersion();
 	unsigned long _sintillaModEventMask = SC_MOD_DELETETEXT | SC_MOD_INSERTTEXT | SC_PERFORMED_UNDO | SC_PERFORMED_REDO | SC_MOD_CHANGEINDICATOR;
