@@ -37,6 +37,10 @@ static const int LF = 0x0A;
 
 long Buffer::_recentTagCtr = 0;
 
+// Invalid characters for a file name
+// Refer: https://docs.microsoft.com/en-us/windows/desktop/FileIO/naming-a-file
+// Including 'tab' and 'return/new line' characters
+const wchar_t* fileNameInvalidChars = L"\\/:*?\"<>|\t\r\n";
 
 namespace // anonymous
 {
@@ -235,7 +239,7 @@ void Buffer::updateTimeStamp()
 
 
 // Set full path file name in buffer object,
-// and determinate its language by its extension.
+// and determine its language by its extension.
 void Buffer::setFileName(const wchar_t *fn)
 {
 	NppParameters& nppParamInst = NppParameters::getInstance();
@@ -251,7 +255,7 @@ void Buffer::setFileName(const wchar_t *fn)
 	_isFromNetwork = PathIsNetworkPath(fn);
 
 	// for _lang
-	LangType determinatedLang = L_TEXT;
+	LangType determinedLang = L_TEXT;
 	wchar_t *ext = PathFindExtension(_fullPathName.c_str());
 	if (*ext == '.') // extension found
 	{
@@ -261,34 +265,34 @@ void Buffer::setFileName(const wchar_t *fn)
 		const wchar_t* langName = nppParamInst.getUserDefinedLangNameFromExt(ext, _fileName);
 		if (langName)
 		{
-			determinatedLang = L_USER;
+			determinedLang = L_USER;
 			_userLangExt = langName;
 		}
 		else // if it's not user lang, then check if it's supported lang
 		{
 			_userLangExt.clear();
-			determinatedLang = nppParamInst.getLangFromExt(ext);
+			determinedLang = nppParamInst.getLangFromExt(ext);
 		}
 	}
 
-	if (determinatedLang == L_TEXT)	// language can probably be refined
+	if (determinedLang == L_TEXT)	// language can probably be refined
 	{
 		if ((wcsicmp(_fileName, L"makefile") == 0) || (wcsicmp(_fileName, L"GNUmakefile") == 0))
-			determinatedLang = L_MAKEFILE;
+			determinedLang = L_MAKEFILE;
 		else if (wcsicmp(_fileName, L"CmakeLists.txt") == 0)
-			determinatedLang = L_CMAKE;
+			determinedLang = L_CMAKE;
 		else if ((wcsicmp(_fileName, L"SConstruct") == 0) || (wcsicmp(_fileName, L"SConscript") == 0) || (wcsicmp(_fileName, L"wscript") == 0))
-			determinatedLang = L_PYTHON;
+			determinedLang = L_PYTHON;
 		else if ((wcsicmp(_fileName, L"Rakefile") == 0) || (wcsicmp(_fileName, L"Vagrantfile") == 0))
-			determinatedLang = L_RUBY;
+			determinedLang = L_RUBY;
 		else if ((wcsicmp(_fileName, L"crontab") == 0) || (wcsicmp(_fileName, L"PKGBUILD") == 0) || (wcsicmp(_fileName, L"APKBUILD") == 0))
-			determinatedLang = L_BASH;
+			determinedLang = L_BASH;
 	}
 
 	updateTimeStamp();
 
 	BufferStatusInfo lang2Change = BufferChangeNone;
-	if (!_hasLangBeenSetFromMenu && (determinatedLang != _lang || _lang == L_USER))
+	if (!_hasLangBeenSetFromMenu && (determinedLang != _lang || _lang == L_USER))
 	{
 		if (_isLargeFile)
 		{
@@ -296,7 +300,7 @@ void Buffer::setFileName(const wchar_t *fn)
 		}
 		else
 		{
-			_lang = determinatedLang;
+			_lang = determinedLang;
 			lang2Change = BufferChangeLanguage;
 		}
 	}
@@ -304,6 +308,44 @@ void Buffer::setFileName(const wchar_t *fn)
 	doNotify(BufferChangeFilename | BufferChangeTimestamp | lang2Change);
 }
 
+void Buffer::normalizeTabName(wstring& tabName)
+{
+	if (!tabName.empty())
+	{
+		// remove leading/trailing spaces
+		trim(tabName);
+
+		// remove invalid characters
+		wstring tempStr;
+		for (wchar_t ch : tabName)
+		{
+			bool isInvalid = false;
+			for (const wchar_t* p = fileNameInvalidChars; *p != L'\0'; ++p)
+			{
+				if (ch == *p)
+				{
+					isInvalid = true;
+					break;
+				}
+			}
+
+			if (!isInvalid)
+				tempStr += ch;
+		}
+		tabName = tempStr;
+
+		// restrict length
+		if (tabName.length() >= langNameLenMax - 1)
+		{
+			tempStr = tabName.substr(0, langNameLenMax - 1);
+			tabName = tempStr;
+		}
+
+		// remove leading/trailing spaces again
+		trim(tabName);
+	}
+}
+
 
 bool Buffer::checkFileState() // returns true if the status has been changed (it can change into DOC_REGULAR too). false otherwise
 {
@@ -705,7 +747,7 @@ void FileManager::init(Notepad_plus * pNotepadPlus, ScintillaEditView * pscratch
 {
 	_pNotepadPlus = pNotepadPlus;
 	_pscratchTilla = pscratchTilla;
-	_pscratchTilla->execute(SCI_SETUNDOCOLLECTION, false);	//dont store any undo information
+	_pscratchTilla->execute(SCI_SETUNDOCOLLECTION, false);	//don't store any undo information
 	_scratchDocDefault = (Document)_pscratchTilla->execute(SCI_GETDOCPOINTER);
 	_pscratchTilla->execute(SCI_ADDREFDOCUMENT, 0, _scratchDocDefault);
 }
@@ -1313,7 +1355,7 @@ SavingStatus FileManager::saveBuffer(BufferID id, const wchar_t* filename, bool
 			freeBytesForUser.QuadPart += fileSize;
 		}
 
-		// determinate if free space is enough
+		// determine if free space is enough
 		if (freeBytesForUser.QuadPart < buffer->docLength())
 			return SavingStatus::NotEnoughRoom;
 	}
@@ -1400,10 +1442,10 @@ SavingStatus FileManager::saveBuffer(BufferID id, const wchar_t* filename, bool
 		buffer->setFileName(fullpath);
 
 		// if not a large file and language is normal text (not defined)
-		// we may try determinate its language from its content 
+		// we may try determine its language from its content 
 		if (!buffer->isLargeFile() && buffer->_lang == L_TEXT)
 		{
-			LangType detectedLang = detectLanguageFromTextBegining((unsigned char*)buf, lengthDoc);
+			LangType detectedLang = detectLanguageFromTextBeginning((unsigned char*)buf, lengthDoc);
 
 			// if a language is detected from the content
 			if (detectedLang != L_TEXT)
@@ -1591,7 +1633,7 @@ int FileManager::detectCodepage(char* buf, size_t len)
 	return codepage;
 }
 
-LangType FileManager::detectLanguageFromTextBegining(const unsigned char *data, size_t dataLen)
+LangType FileManager::detectLanguageFromTextBeginning(const unsigned char *data, size_t dataLen)
 {
 	struct FirstLineLanguages
 	{
@@ -1831,7 +1873,7 @@ bool FileManager::loadFileData(Document doc, int64_t fileSize, const wchar_t * f
 				if (!isLargeFile && fileFormat._language == L_TEXT)
 				{
 					// check the language du fichier
-					fileFormat._language = detectLanguageFromTextBegining((unsigned char *)data, lenFile);
+					fileFormat._language = detectLanguageFromTextBeginning((unsigned char *)data, lenFile);
 				}
 
                 isFirstTime = false;
