@@ -204,7 +204,7 @@ void TabBar::setImageList(HIMAGELIST himl)
 }
 
 
-void TabBar::reSizeTo(RECT & rc2Ajust)
+void TabBar::reSizeTo(RECT & rc2Adjust)
 {
 	RECT rowRect{};
 	int rowCount = 0, tabsHight = 0;
@@ -212,8 +212,8 @@ void TabBar::reSizeTo(RECT & rc2Ajust)
 	// Important to do that!
 	// Otherwise, the window(s) it contains will take all the resouce of CPU
 	// We don't need to resize the contained windows if they are even invisible anyway
-	display(rc2Ajust.right > 10);
-	RECT rc = rc2Ajust;
+	display(rc2Adjust.right > 10);
+	RECT rc = rc2Adjust;
 	Window::reSizeTo(rc);
 
 	// Do our own calculations because TabCtrl_AdjustRect doesn't work
@@ -245,13 +245,13 @@ void TabBar::reSizeTo(RECT & rc2Ajust)
 
 	if (isVertical)
 	{
-		rc2Ajust.left += tabsHight;
-		rc2Ajust.right -= tabsHight;
+		rc2Adjust.left += tabsHight;
+		rc2Adjust.right -= tabsHight;
 	}
 	else
 	{
-		rc2Ajust.top += tabsHight;
-		rc2Ajust.bottom -= tabsHight;
+		rc2Adjust.top += tabsHight;
+		rc2Adjust.bottom -= tabsHight;
 	}
 }
 
@@ -666,6 +666,7 @@ LRESULT TabBarPlus::runProc(HWND hwnd, UINT Message, WPARAM wParam, LPARAM lPara
 
 		case NPPM_INTERNAL_REFRESHDARKMODE:
 		{
+			NppDarkMode::autoThemeChildControls(hwnd); // for updown child
 			NppDarkMode::setDarkTooltips(hwnd, NppDarkMode::ToolTipsType::tabbar);
 			setCloseBtnImageList();
 			setPinBtnImageList();
@@ -851,7 +852,7 @@ LRESULT TabBarPlus::runProc(HWND hwnd, UINT Message, WPARAM wParam, LPARAM lPara
 			return TRUE;
 		}
 
-		case WM_RBUTTONDOWN :	//rightclick selects tab aswell
+		case WM_RBUTTONDOWN :	//rightclick selects tab as well
 		{
 			// TCS_BUTTONS doesn't select the tab
 			if (::GetWindowLongPtr(_hSelf, GWL_STYLE) & TCS_BUTTONS)
@@ -1534,7 +1535,7 @@ void TabBarPlus::drawItem(DRAWITEMSTRUCT* pDrawItemStruct, bool isDarkMode)
 			brushColour = colorActiveBg;
 		}
 		
-		if (_currentHoverTabItem == nTab && brushColour != colorActiveBg) // hover on a "darker" inactive tab
+		if (_currentHoverTabItem == nTab && brushColour != colorActiveBg && !_isDragging) // hover on a "darker" inactive tab
 		{
 			HLSColour hls(brushColour);
 			brushColour = hls.toRGB4DarkModeWithTuning(15, 0); // make it lighter slightly
